=======
History
=======


0.1.1 (unreleased)
------------------

* Fix rating css selector
* Adapt for new site imdb


0.1.0 (2018-04-06)
------------------

* Add Imdb spider with scrapping: rate, title, url and date
